/* $Id: TableHandling.js,v 1.63.2.1 2006/12/01 05:39:54 hari Exp $ */
String.prototype.trim = function() {
  var x=this;
  x=x.replace(/^\s*(.*)/, "$1");
  x=x.replace(/(.*?)\s*$/, "$1");
  return x;
}

/**
* Resets the navigation state for the table.
*/
function resetNavigationState(id)
{
  var uniqueId = getUniqueId(id);
  updateState(uniqueId, "_FI", "1");      
  updateState(uniqueId, "_TI", null);
  updateState(uniqueId, "_PN", null);
  stateData[uniqueId]["_VMD"]= '1';
}

/**
 * Sorts the table view as represented by the id attribute with the column as
 * indicated by the columnName. Any navigation done so far will be lost and the
 * first page will be shown. Also if 'customizetype' attribute of the view is
 * set to PERSONALIZE, then the sorted column will be maintained on a per user
 * basis.
 *
 * @param	id		the uniqueId/referenceId for which the data is 
 * 				to be sorted.
 * @param	columnName	the name of the column by which the data should
 * 				be sorted.
 */
function sortData(id, columnName){
	var uniqueId = getUniqueId(id);
	updateState(uniqueId, "_SB", columnName);
        resetNavigationState(id);
	var order = stateData[uniqueId]["_SO"];
	if(order == "D"){
		updateState(uniqueId, "_SO","A");
		order = "ASC";
	}
	else{
		updateState(uniqueId, "_SO","D");
		order = "DESC";
	}
	//Setting _MP (Modified Property) as always the sort columns
	// are set.This would result in table getting personalized
	// always.
        stateData[uniqueId]["_MP"] = "_SB";
	refreshSubView(uniqueId);
}

/**
 * Fetches and displays the data for the specified range. The index from which
 * the data should be fetched should be specified as the fromIndex.
 *
 * @param	id		the uniqueId/referenceId for which the data is 
 * 				to be shown.
 * @param	fromIndex	the index from which the next set of data
 * 				should be fetched.
 */
function showRange(id, fromIndex){
	var uniqueId = getUniqueId(id);
	var _pl = parseInt(stateData[uniqueId]["_PL"],10);
	var _pn = 1;
	// The _pn will be determined using the fromIndex and pagelength.
	_pn = parseInt(fromIndex / _pl, 10) + 1;
	updateState(uniqueId, "_FI", fromIndex);
	updateState(uniqueId, "_PN", _pn + "");
	stateData[uniqueId]["_VMD"]= '1';
	refreshSubView(uniqueId);
}

/**
 * Fetches and displays the data for the specified pageLength. The page will be
 * reloaded with the first set of data for the given pageLength(i.e fromIndex
 * will be 1 for the loaded view).
 *
 * @param	id		the uniqueId/referenceId for which the data is 
 * 				to be shown.
 * @param	pageLength	the pageLength which should be used to fetch
 * 				the data.
 */
function showRangeForLength(id, pageLength){
	var uniqueId = getUniqueId(id);
	updateState(uniqueId, "_PL", pageLength);
        resetNavigationState(uniqueId);

	//Setting _MP (Modified Property) as always the sort columns
	// are set.This would result in table getting personalized
	// always.
        stateData[uniqueId]["_MP"] = "_PL";
	refreshSubView(uniqueId);
}

/**
 * Fetches the data applying the search data specified through the spot search
 * fields. First the data is validated(i.e whether string data is entered for
 * numeric column etc..) and if validation succeeds, data will be retrieved for
 * the search criteria and shown. This uses, framework's validation methods.
 * The alerttype used will be 'Custom'.
 *
 * @param	id		the uniqueId/referenceId for which the data is 
 * 				to be shown.
 * @param	formObj		form object of the table view.
 */
function fetchSpotSearchData(id, formObj){
	return updateFormValues(id, formObj);
}

// The below is the original method for the fetchSpotSearchData. Since the
// method name was not a meaningful one, the new method had been added.

/**
 * Fetches the data applying the search data specified through the spot search
 * fields. First the data is validated(i.e whether string data is entered for
 * numeric column etc..) and if validation succeeds, data will be retrieved for
 * the search criteria and shown. This uses, framework's validation methods.
 * The alerttype used will be 'Custom'.
 *
 * @param	id		the uniqueId/referenceId for which the data is 
 * 				to be shown.
 * @param	formObj		form object of the table view.
 */
function updateFormValues(id, formObj){
	var uniqueId = getUniqueId(id);
	var length = formObj.elements.length;
	if(!validateForm(formObj)){
		return false;
	}
	var searchColumns = "";
	var searchValues = "";
	var initial = true;
	for(i = 0; i < length; i++){
		type = formObj.elements[i].type;
		if(type == "text"){
			name = formObj.elements[i].name;
			value = formObj.elements[i].value;
			if(value != null && value.trim() != ""){
				if(!initial){
					searchColumns = searchColumns + ",";
					searchValues = searchValues + ",";
				}
				searchColumns = searchColumns + name;
				searchValues = searchValues + value;
				initial = false;
			}
		}
	}

	updateState(uniqueId, "SEARCH_COLUMN", searchColumns);
	updateState(uniqueId, "SEARCH_VALUE", searchValues);
        resetNavigationState(uniqueId);
	refreshSubView(uniqueId);
	return false;
}

// This method can be removed .....


/**
 * Creates a javascript row for values passed. Each created row value is added
 * to the correponding array represented by the tablealias, at the position as
 * indicated by count. 
 *
 * @param	id		the uniqueId/referenceId for which the data is 
 * 				to be shown.
 * @param	tableAlias	the table for which javascript row is added.
 * @param	count		the index at which the javascript row should be
 * 				maintained for the table specified by
 * 				tableAlias.
 * @param	rowValues	the data as a javascript array.
 */
function createRow(id, tableAlias, count, rowValues){
	var uniqueId = getUniqueId(id);
	var referenceId = getReferenceId(id);
	var vName = stateData[uniqueId]["_VN"];
	rowObject = new Object();
	var size = rowValues.length;
	for(i=0; i < size; i++){
		var colArr = eval("parent." + uniqueId + "_" + tableAlias + "_ColumnNames");
		if(colArr == null){
			return;
		}
		rowObject[colArr[i]] = rowValues[i];		
	}  
	var table = eval("parent." + "T"+referenceId + "_" + tableAlias);
	table[count] = rowObject;
}

/**
 * Sets alternate colors for the rows of a table indicated by id. The odd and
 * even row colors should be specified as arguments. A sample usage would be
 * 	<br>alternateRows('myTable','oddRow','evenRow');</br>.
 * where oddRow and evenRow are the css classes that should be alternatively
 * applied.
 *
 * @param       id              the table of the required table.
 * @param	evenClass	the class that should be used for even rows.	
 * @param	oddClass	the class that should be used for odd rows.	
 */
function alternateRows(id) {
	var even = false;
	var evenClass = arguments[1] ? arguments[1] : "#fff";
	var oddClass = arguments[2] ? arguments[2] : "#eee";
	var table = document.getElementById(id);
	if (! table) { return; }
	var tbodies = table.getElementsByTagName("tbody");
	for (var h = 0; h < tbodies.length; h++) {
		var trs = tbodies[h].getElementsByTagName("tr");
		for (var i = 0; i < trs.length; i++) {
			var tds = trs[i].getElementsByTagName("td");
			for (var j = 0; j < tds.length; j++) {
				var mytd = tds[j];
				mytd.setAttribute("class",even ? evenClass : oddClass);
			}
			even =  ! even;
		}
	}
}

/**
 * Closes the spot search fields and reloads the table with out the spot search
 * criteria. 
 *
 * @param	sourceId	the id of the object containing the search
 * 				fields so that they can be closed
 * @param	formObj		the form object present in the table view.
 * @param       refId		the uniqueId/referenceId of the table view.
 */
function closeSearch(sourceId, formObj, refId)
{
	document.getElementById(sourceId).className = "hide";
	document.getElementById(refId+"_OS").className = "tableSearchButton";
	document.getElementById(refId+"_CS").className = "hide";
	var isValPresent = false;
	if(formObj.elements != null){
		var size = formObj.elements.length;
		for(var count = 0; count < size; count++){
			var element = formObj.elements[count];
			if(element.type == "text"){
				if(element.value != ""){
					element.value = "";
					isValPresent = true;
				}
			}
		}
	}		
	if(isValPresent){
		updateFormValues(getUniqueId(refId), formObj);
	}
}

/**
 * Opens the spot search fields. 
 *
 * @param	sourceId	the id of the object containing the search
 * 				fields so that they can be opened
 * @param	formObj		the form object present in the table view.
 * @param       refId		the uniqueId/referenceId of the table view.
 */
function openSearch(sourceId, formObj, uniqueId){
	document.getElementById(sourceId).className = "searchRow";
	document.getElementById(uniqueId+"_OS").className = "hide";
	document.getElementById(uniqueId+"_CS").className = "tableSearchCloseButton";

	if(formObj.elements != null){
		var size = formObj.elements.length;
		for(var count = 0; count < size; count++){
			var element = formObj.elements[count];
			if(element.type == "text"){
				element.focus();
				break;
			}
		}
	}
}

/**
 * Fetches the data applying the data as specified by the Select element object.
 *
 * @param	id		the uniqueId/referenceId for which the data is 
 * 				to be shown.
 * @param	select		the select object from which the search data
 * 				should be retrieved. The name of the select
 * 				field should match the columnalias specified in
 * 				the selectquery.
 */
function updateSearchData(id, select){
	var uniqueId = getUniqueId(id);
	searchColumn = select.name;
	searchValue = select.value;
	updateState(uniqueId, "SEARCH_COLUMN", searchColumn);
	updateState(uniqueId, "SEARCH_VALUE", searchValue);
	updateState(uniqueId, "_SB", null);
	stateData[uniqueId]["_VMD"]= '1';
        resetNavigationState(uniqueId);

	refreshSubView(uniqueId);
	return false;
}

/**
 * Displays the message in a div, at the position represented by the curId
 * argument. The div will follow the custom alert of a form, meaning the css
 * classes used will be the same. The main class will names 'completeMessage'
 * to allow applications differentiate between message and error divs.
 * 
 * @param	message		the message to be displayed.
 * @param	curId		the id of the element, where the message div
 * 				should be positioned. 
 */
function showCompleteMessage(curId){
	var message = parent[curId]["MSG"];
	// In getEscapedString method \r\n is replaced as \n\n. Hence the below replace
	message = message.replace(/\n\n/gi,"<br>");
	message = message.replace(/\n/gi,"<br>");
	showCustomMessage(message, document.getElementById(curId), 'completeMessage');
}

/**
 * Hides the message div.
 */
function hideCompleteMessage(){
	document.getElementById("completeMsgDiv").className = "hide";
}

/**
 * Shows the trimmed message and provides a link over it to display the
 * complete text. Clicking this link will show the, complete message in a
 * custom div.
 *
 * @param	trimmedMsg	the trimmed message to be displayed.
 * @param	completeMsg	the complete message that should be shown on
 * 				click of the trimmed message.
 * @param	insertionId	the id of the place where the custom div should
 * 				be positioned.
 * @param	action		----- not supported ----.
 * @param	destDoc		the document object to be used.
 */
function defaultTrimmedMessageDisplayer(trimmedMsg, completeMsg, insertionId, action, destDoc){
	parent[insertionId] = new Object();
	parent[insertionId]["MSG"] = completeMsg;
	var data = "<a  href=\"javascript:showCompleteMessage('" + insertionId + "')\">" + trimmedMsg + "</a>";
	destDoc.getElementById(insertionId).innerHTML = data;
}

/**
 * Shows the trimmed message alone
 *
 * @param	trimmedMsg	the trimmed message to be displayed.
 * @param	completeMsg	----- not supported ----.
 * @param	insertionId	----- not supported ----.
 * @param	action		----- not supported ----.
 * @param	destDoc		the document object to be used.
 */

function showTrimmedMessage(trimmedMsg, completeMsg, insertionId, action, destDoc){
	var data = "";
	if(action != null && action != "" && action != "null"){
		data = data.concat("<a href='" + action + "'>");
	}
	data = data.concat(trimmedMsg);
	if(action != null && action != "" && action != "null"){
		data = data.concat("</a>");
	}	
	destDoc.getElementById(insertionId).innerHTML = data;
}

/**
 * Shows the trimmed message and provides a button near it, onClick of which
 * the complete text will be shown. This also supports an action link for the
 * trimmed content. The current document should be passed since there is a
 * possibility for the table to load both the the main window and in the
 * response iframe. The invoker will be button element with the css class set
 * as messageInvoker
 *
 * @param	trimmedMsg	the trimmed message to be displayed.
 * @param	completeMsg	the complete message that should be shown on
 * 				click of the image.
 * @param	insertionId	the id of the place where the custom div should
 * 				be positioned.
 * @param	action		----- not supported ----.
 * @param	destDoc		the document object to be used.
 */
function showTrimmedMessageOnImageClick(trimmedMsg, completeMsg, insertionId, action, destDoc){
	var data = "";
	if(action != null && action != "" && action != "null"){
		data = data.concat("<a href='" + action + "'>");
	}
	data = data.concat(trimmedMsg);
	if(action != null && action != "" && action != "null"){
		data = data.concat("</a>");
	}	
	parent[insertionId] = new Object();
	parent[insertionId]["MSG"] = completeMsg;
	data = data.concat("<button class='messageInvoker' onClick=\"javascript:showCompleteMessage('" + insertionId + "');return false\"></button>");
	destDoc.getElementById(insertionId).innerHTML = data;
}

/**
 * Shows the trimmed message and provides a button near it, onMouseOver of which
 * the complete text will be shown. This also supports an action link for the
 * trimmed content. The invoker will be button element with the css class set
 * as messageInvoker
 *
 * @param	trimmedMsg	the trimmed message to be displayed.
 * @param	completeMsg	the complete message that should be shown on
 * 				mouse over of the image.
 * @param	insertionId	the id of the place where the custom div should
 * 				be positioned.
 * @param	action		----- not supported ----.
 * @param	destDoc		the document object to be used.
 */
function showTrimmedMessageOnMouseOver(trimmedMsg, completeMsg, insertionId, action, destDoc){
	var data = "";
	if(action != null && action != "" && action != "null"){
		data = data.concat("<a href='" + action + "'>");
	}
	data = data.concat(trimmedMsg);
	if(action != null && action != "" && action != "null"){
		data = data.concat("</a>");
	}	
	parent[insertionId] = new Object();
	parent[insertionId]["MSG"] = completeMsg;
	data = data.concat("<button class='messageInvoker' onMouseOver=\"javascript:showCompleteMessage('" + insertionId + "');return false\" onMouseOut=\"hideCustomMessage();return false;\"></button>");
	destDoc.getElementById(insertionId).innerHTML = data;
}

/**
 * Shows the trimmed message, onMouseOver of which the complete text will be
 * shown. This also supports an action link for the trimmed content. The
 * invoker will be button element with the css class set as messageInvoker.
 *
 * @param	trimmedMsg	the trimmed message to be displayed.
 * @param	completeMsg	the complete message that should be shown on
 * 				mouse over of the text.
 * @param	insertionId	the id of the place where the custom div should
 * 				be positioned.
 * @param	action		----- not supported ----.
 * @param	destDoc		the document object to be used.
 */
function showMessageOnTextMouseOver(trimmedMsg, completeMsg, insertionId, action, destDoc){
	var data = "";
	if(action != null && action != "" && action != "null"){
		data = data.concat("<a href='" + action + "'>");
	}
	parent[insertionId] = new Object();
	parent[insertionId]["MSG"] = completeMsg;
	data = data.concat("<span onMouseOver=\"javascript:showCompleteMessage('" + insertionId + "');return false\" onMouseOut=\"hideCustomMessage();return false;\">");
	data = data.concat(trimmedMsg);
	data = data.concat("</span>");
	if(action != null && action != "" && action != "null"){
		data = data.concat("</a>");
	}	
	destDoc.getElementById(insertionId).innerHTML = data;
}

/**
 * Displays the column chooser as a dialog. The html data to be displayed in
 * the dialog should be passed through the data attribute.
 * @param	viewName	----- Not Neeed ---- To be Removed.
 * @param	data		the chooser data to be shown in the div.
 */
function displayColumnChooser(menuItemId, srcViewRefId, additionalParams,index) {
        var menuItemObj = getMenuItemObj(menuItemId);
        var url = getURLSuffixed(menuItemObj.ACTIONLINK) + additionalParams;
	showURLInDialog(url, menuItemObj.WINPARAMS);
}


/**
 * Selects the filter.
 */
function selectFilter(id,filterCombo)
{
  var uniqueId = getUniqueId(id);
  updateState(uniqueId,'SELFILTER',filterCombo.value);
  resetNavigationState(id);
  refreshSubView(uniqueId);
}

function showWrappedMessageOnImageClick(trimmedMsg, completeMsg, insertionId, action, destDoc)
{
    var data = "";
    var len = trimmedMsg.length-4;
	if(action != null && action != "" && action != "null"){
	      data = data.concat("<a href='" + action+"'>");
	}
	data = data.concat(trimmedMsg);
	if(action != null && action != "" && action != "null"){
		data = data.concat("</a>");
	}	
	window[insertionId] = new Object();
	window[insertionId]["MSG"] = completeMsg;
	data = data.concat("<button class='messageInvoker' onClick=\"javascript:showWrappedMessage('" + insertionId + "', '" + completeMsg + "',"+ len+");return false\"></button>");
	destDoc.getElementById(insertionId).innerHTML = data;
      
}
function showWrappedMessageOnTextMouseOver(trimmedMsg, completeMsg, insertionId, action, destDoc)
{
    var data = "";
    var len = trimmedMsg.length-16;
    if(action != null && action != "" && action != "null"  )
    {
        data = data.concat("<a href='" + action+"'>");
    }

    parent[insertionId] = new Object();
    data = data.concat("<span  onMouseOver=\"javascript:showWrappedMessage('" + insertionId + "', '" + completeMsg + "',"+ len+");return false\" onMouseOut=\"hideCustomMessage();return false;\">");
    data = data.concat(trimmedMsg);
    data = data.concat("</span>");
    if(action != null && action != "" && action != "null"){
        data = data.concat("</a>");
    }   
    destDoc.getElementById(insertionId).innerHTML = data;
}

function showWrappedMessage(insertionId, completeMsg,length)
{
                              
    var newmsg = "";
    var len = completeMsg.length;
    var brstr = "<br>";
    while(len > length)
    {
        newmsg =  newmsg + completeMsg.substring(0, length) + brstr;
        completeMsg = completeMsg.substring(length , len);
        len = completeMsg.length;
    }
    newmsg = newmsg + completeMsg;
    parent[insertionId]["MSG"] = newmsg;
    showCompleteMessage(insertionId);
}


