//$Id: TooltipHandling.js,v 1.2.2.8 2006/12/07 09:14:12 hari Exp $

Tooltip = Class.create();

window.tooltips = [];
       
Tooltip.prototype = {
	initialize: function(link_id, tooltip_id, options) {
		this.link_el = $(link_id);
		this.tooltip_el = $(tooltip_id);
		this.runningEffect = null;
		
		this.options = {
			queue: { 
				position: "end", 
				scope: "tooltip"+window.tooltips.length, 
				limit: 1
			},
			duration: 1.0,
			effect:"appear",
			offsetLeft: 20,
			offsetTop: 10,
			showEvent: "mouseover",
			hideEvent: "mouseout"
		};		
			
		this.tooltip_el.style.zIndex = "1000";
		this.tooltip_el.style.position = "absolute";
		this.tooltip_el.style.left = "0";
		this.tooltip_el.style.top = "0";		
		Element.hide(this.tooltip_el);		
		
		Object.extend(this.options, options||{});
		Event.observe(this.link_el, this.options.showEvent, this.show.bind(this));

		if(this.options.closelinkId)
		{
			Event.observe($(this.options.closelinkId), this.options.hideEvent, this.hide.bind(this));
		}
		else
		{
			if(this.options.hideEvent != "none")
			{
				Event.observe(this.link_el, this.options.hideEvent, this.hide.bind(this));
			}
			else
			{
				Event.observe(this.tooltip_el,  "mouseout", this.hide.bind(this));
			}
		}
		window.tooltips.push(this);
		Event.observe(this.tooltip_el, "click", this.hide.bind(this));
	},
	
	show: function(event) {
		if(window._currentTT)
		{
			window._currentTT.hide();
		}
		window._currentTT = this;	
		
		var duration = this.options.duration;	

		if (this.runningEffect) {
			var queue = Effect.Queues.get(this.options.queue.scope);
			duration = Math.min(new Date().getTime() - this.runningEffect.startOn, duration);
			queue.remove(this.runningEffect);
		}
		this.runningEffect = Effect[Effect.PAIRS[this.options.effect][0]](this.tooltip_el,
			 Object.extend(Object.extend(
					Object.extend({},
					 this.options),
					 {duration: duration})
					));
							
		var x = Event.pointerX(event) + this.options.offsetLeft;
		Position.prepare();		
		var triggerY = Position.cumulativeOffset(this.link_el)[1];

		var y = triggerY + this.link_el.offsetHeight + this.options.offsetTop;
		var popUp = Element.getDimensions(this.tooltip_el);
		
		var visibleWidth = 
        (window.opera) ? document.body.clientWidth || document.documentElement.clientWidth || window.innerWidth
        : document.documentElement.clientWidth || window.innerWidth || document.body.clientWidth;
		var visibleHeight = 
        (window.opera) ? document.body.clientHeight || document.documentElement.clientHeight || window.innerHeight
        : window.innerHeight || document.body.clientHeight || document.documentElement.clientHeight;
        
	
		if (x + popUp.width + this.options.offsetLeft > (Position.deltaX + visibleWidth)) 
			x = Math.max( this.options.offsetLeft, ((Position.deltaX + visibleWidth) - popUp.width - 107 - this.options.offsetLeft));
		if (y + popUp.height + this.options.offsetTop > (Position.deltaY + visibleHeight)) {
			y = triggerY - popUp.height - this.options.offsetTop;
		}
		this.tooltip_el.style.left = x+"px";
		this.tooltip_el.style.top = y+"px";	
	},
	
	hide: function(event) {
	
		if(event && event.type == "click" && Event.element(event) == this.link_el)
		{
			return;
		}
	
		if(event && this.options.hideEvent == "none" && event.type == "mouseout")
		{
			//refer doc here for logic used below
			//http://www.quirksmode.org/js/events_mouse.html			
			var tg = Event.element(event);
			if (tg.nodeName != 'DIV') 
			{
				return;
			}
			
			var reltg = (event.relatedTarget) ? event.relatedTarget : event.toElement;
			while (reltg && reltg != tg && reltg.nodeName != 'BODY')
			{
				reltg = reltg.parentNode
			}
			if (reltg == tg) 
			{	
				return;
			}
		}
		var duration = this.options.hideduration;
		if(!duration)
		{
			duration = this.options.duration;
		}
		if (this.runningEffect) {
			var queue = Effect.Queues.get(this.options.queue.scope);
			duration = Math.min(new Date().getTime() - this.runningEffect.startOn, duration);
			queue.remove(this.runningEffect);
		}		
	
		this.runningEffect = Effect[Effect.PAIRS[this.options.effect][1]](this.tooltip_el, Object.extend(Object.extend(
			Object.extend({}, this.options), {duration: duration})));
	}
}


function registerNormalTooltip(link_id, tooltip_id)
{
	var ttip = new Tooltip(link_id, tooltip_id,
							{duration:0.5});
}

function registerMouseMoveTooltip(link_id, tooltip_id)
{
	var ttip = new Tooltip(link_id, tooltip_id, {showEvent:"mousemove"});
}

function registerMenuPopupTooltip(link_id, tooltip_id)
{
	document.getElementById(tooltip_id).className="MenuPopupTooltipBox";
	var ttip = new Tooltip(link_id, tooltip_id,
					{showEvent:"click", hideEvent:"click",
					offsetLeft: 23, offsetTop: -12,
					duration:0.0});
}


function registerCalloutTooltip(link_id, tooltip_id)
{
	var ttip = new Tooltip(link_id, tooltip_id,
		{showEvent:"mousemove",offsetLeft: 5, offsetTop: 5});
}

function registerClickBubbleTooltip(link_id, tooltip_id,closelink_id)
{
	var ttip = new Tooltip(link_id, tooltip_id,
		{showEvent:"click",hideEvent:"click", offsetLeft: 5, offsetTop: 5,
		closelinkId:closelink_id});
}

function registerMouseClickTooltip(link_id, tooltip_id, closelink_id)
{
	var ttip = new Tooltip(link_id, tooltip_id,
				 				{showEvent:"click",
				  				 hideEvent:"click",
				  				 closelinkId:closelink_id});
}


/*function registerAjaxTooltip(link_id, tooltip_id)
{
	var acti = $(link_id);
	var href = acti.getAttribute("href");
	acti.removeAttribute("href");	

	Event.observe(acti, "click", fetchpage.bind(this));
}*/
