/**
 * $Id: MenuAPI.js,v 1.61.2.1 2006/11/18 09:10:50 hari Exp $
 */

/**
 * Contains the instances of all the menuitems. The insyance can be fetched by
 * passing the menuitemname.
 */
var _MENU_MODEL_MGR = new Object();

/**
 * Creates a new MenuItem object for the given menuitem and adds it to the
 * manager.
 */
function createMenuItem(menuItemName, properties){
	var menuItemObj = new MenuItem(menuItemName, properties);
	_MENU_MODEL_MGR[menuItemName] = menuItemObj;
}


/**
 * Gets then MenuItem object for the given menuitem.
*/

function getMenuItemObj(menuItemName)
{
  return _MENU_MODEL_MGR[menuItemName];
}

/**
 * Creates a new MenuItem object for the given menuitem and properties. 
 * <br><b>Note:</b> All instance methods are prefixed with _MI_. These can be
 * directly accessed like <i>getMenuItemObj('TestMenuItem').getActionURL(...)</i>
 */
function MenuItem(menuItemName, properties){  
	// Properties
	this.MENUITEMID = menuItemName;
	this.DISPLAYNAME = properties[0];
	this.IMAGE = properties[1];
	this.CONFIRMSTRING = properties[2];
	this.ACTIONLINK = getURLSuffixed(properties[3]);
	this.LINKPARAMS = properties[4];
	this.TARGET = properties[5];
	this.WINPARAMS = properties[6];
	this.JSMETHODNAME = properties[7];
	this.REFRESHLEVEL = properties[8];
	this.ACTIONTYPE = properties[9];
        
        this.getParams = _MI_getParams;
        this.isAtleastOneChecked = _MI_isAtleastOneChecked;
        this.confirmAction = _MI_confirmAction;
        this.getActionURL = _MI_getActionURL;
        this.invokeActionURL = _MI_invokeActionURL;
        this.invokeMenuAction = _MI_invokeMenuAction;
}

/** 
 *  Returns the merged parameters based on menuitem's params and the additional params passed.
 *  <br><b>Note:</b> 
 *  <ul><li>additionalParams can be <b>NULL</b>.</li>
 *  <li> Can return <b>null</b> if both additionalParams and menuitem's params are null.
 *
 **/
function _MI_getParams(additionalParams)
{
    if(additionalParams != null)
    {
 	if(this.LINKPARAMS == null)
        {
	    return additionalParams;
        }       
	else  
        {
	    return this.LINKPARAMS + "&" + additionalParams;
	}
     }
     else
     {
         return this.LINKPARAMS;
     }
}


/**
 * Executes the action for the menuItemId that is passed. If additionalParams
 * is passed, then this will also be added to the existing params list and
 * executed.
 * <br><br>
 *  If user has configured his own javascript action for menu, then
 * that script will be used. Otherwise menuitem's invokeMenuAction
 *  will be called
 *
 * @param	menuItemId	menuitem for which the action is to be done.
 * @param	srcViewRefId	srcViewRefId from which the data is to be taken.
 * @param	additionalParams	any additional query params. Dynamic
 * 					values should be in the templatized 
 *					form. Can be null.
 * @param       index   the index from which the datamodel values for the params 
 *              should be fetched. Can be <b>Null</b>. If it is null, then the values
 *              are taken based on the rowselection.
 * <br><b>Note:</b>
 * <br><b>additionalParams</br> that is passed should be in the templatized format. A sample
 * entry could be 'ID=$D{ID}&NAME=$S{RES_NAME}' where $D represents a data
 * present in the Datamodel, $S represents a data present in the State. The
 * value in the braces represents the value that should be taken from the
 * respective scope. The other scope is 'request' indicated by $R{}. Static
 * values can be given directly as key value pairs.</li>
 * </ul>
 */
function invokeMenuAction(menuItemId, srcViewRefId, additionalParams,index){
  
  var menuItemObj = getMenuItemObj(menuItemId);
  if(menuItemObj.JSMETHODNAME != null)
  { 
     parent[menuItemObj.JSMETHODNAME](menuItemId, srcViewRefId, additionalParams,index);
  }
  else
  {
     menuItemObj.invokeMenuAction(srcViewRefId,additionalParams,index);
  }
}


/**
 * Handles the complete flow for a menu.
 *  <ul><li>Checks if atleast one row is passed/checked</li>
 *      <li>Confirms the action with the user if configured</li>
 *      <li>Creates the url based on the params configured/passed</li>
 *      <li>Invokes the URL </li></ul>
 * 
 **/
function _MI_invokeMenuAction(srcViewRefId, additionalParams,index){

    if(!this.isAtleastOneChecked(srcViewRefId,additionalParams,index))
    {
        return;
    }     

    if(!this.confirmAction()){
        return;
    }     
    this.invokeActionURL(this.getActionURL(srcViewRefId,
              additionalParams,index));
}

/**
 * Checks and shows error if atleast one row needs to be selected in the source view. 
 * The check is based upon whether the params has any datamodel template references.
 *
 **/
function _MI_isAtleastOneChecked(srcViewRefId, additionalParams,index)
{
  if(index != null)
  {
    return true;
  }
    if(hasDataModelTplReference(this.getParams(additionalParams)))
    {
      if(!getTableModel(srcViewRefId).isAtleastOneChecked("Select atleast one row to " + this.DISPLAYNAME))
      {
        return false;
      }
    }
    return true;
}


/**
 *  Throws a confirm box to the user. If the
 * CONFIRMSTRING is configured then, a confirm dialog will appear with the
 * configured string and the result will be returned, else null will be
 * returned.
 */
function _MI_confirmAction()
{
  var confirmStr = this.CONFIRMSTRING;
  var confirmResult = true;
  if(confirmStr) {
    confirmResult = confirm(confirmStr);
  }
  return confirmResult;
}



/**
 * Method in MenuItem Object. Returns the action url for the MenuItem. This
 * includes the replaced query string.
 *
 * @return	the action url.
 */
function _MI_getActionURL(srcViewRefId, additionalParams,index) {
  var url = this.ACTIONLINK;
  if(srcViewRefId != null) {
    url += "ACTION_SOURCE=" + getUniqueId(srcViewRefId) + "&";
  }
  var params = this.getParams(additionalParams);
  if(params != null) {
    var selIndices = null;
    if(hasDataModelTplReference(params))
    {
       selIndices = (index == null)? getTableModel(srcViewRefId).getSelectedRowIndices():[index];
    }
    url = url + constructURLParams(params, srcViewRefId,selIndices);
  }
  return url;
}


/**
 * Opens the url passed based on the  configurations such as target,window params
 * as specified in the MenuItem
 * @param srcViewRefId   The source view's refid/uniqueid. Can be null.
 */
function _MI_invokeActionURL(url,srcViewRefId)
{
	var winParams = this.WINPARAMS;
	var target = this.TARGET;
	var refreshLevel = this.REFRESHLEVEL;
	if(this.ACTIONTYPE == "POST"){
		var formObj = createForm(this.ACTIONLINK, this.TARGET, "POST", "MI_" + this.MENUITEMID);
		var queryString = url.substring(url.indexOf("?") +1, url.length);
		var params = queryString.split("&");
		for(var i=0; i<params.length;i++){
			var param = params[i];
			if(param.indexOf("=") != 0 && param.length>3){
				var paramName = param.substring(0, param.indexOf("="));
				var paramValue = param.substring(param.indexOf("=")+1, param.length);
				var newElement = document.createElement("input");
				setAttrOnFrm(newElement, "type","hidden");
				setAttrOnFrm(newElement, "name", paramName);
				setAttrOnFrm(newElement, "value", paramValue);
				formObj.appendChild(newElement);
			}
		}
		document.body.appendChild(formObj);
		handleStateForForm(formObj, srcViewRefId);
		formObj.submit();
		return;
	}
	if(((target == null) || (target == '_self')) && (srcViewRefId != null))
	{
		processURLBasedOnLevel(url, srcViewRefId, refreshLevel);
	}
	else
	{
		openURL(url, target, winParams);
	}
}


/**
 * Internal method.
 **/
function evalViewFun(funName,funString)
{
  if(parent[funName])
  {
    return;
  } 
  parent[funName] = new Function("index","viewName",funString);
}


/**
 * Fetches the values from the scopes as specified in the querystring, for the
 * given indices and templatized params.
 *
 * @param	linkParams	The templatized params.
 * @param	refId	        The referenceid/uniqueId of the view.
 * @param	selectedIndices	the selected row indeices as an array.
 * 				replaced by the appropriate values.
 * @return	the replaced query string.
 */
function constructURLParams(linkParams,refId,selectedIndices)
{
  if(refId == null){ return linkParams;}
  var uniqueId = getUniqueId(refId);
  var paramsMap = parseTemplateParams(linkParams);
  var reqParams = stateData[uniqueId]["_D_RP"];      
  var reqMap = null;
  var url = "";
  var tblModel = getTableModel(uniqueId);
  if(reqParams != null){
    reqMap = parseRequestParams(reqParams);
  }
  for(var i = 0; i < paramsMap.length; i++){
    var details = paramsMap[i];
    if(details[2] == 1 && reqMap[details[1]] != null) {
      var value = reqMap[details[1]];
      for(var cnt = 0; cnt < value.length; cnt++){
        url = url + "&" + details[0] + "=" + value[cnt];
      }
    }
    else if(details[2] == 2) {
      url = url + "&" + details[0] + "=" + stateData[uniqueId][details[1]];
    }
    else if(details[2] == 3){
      var colName = details[1];
      var colIndex = tblModel.getColumnIndex(colName);	
      if(selectedIndices != null && selectedIndices.length > 0){
        for(var count=0; count < selectedIndices.length; count++){
          var rowVal = selectedIndices[count];
          var colVal = tblModel.getValueAt(rowVal, colIndex);
          if(colVal != null)
          {
            url = url + "&" + details[0] + "=" + colVal;
          }
        }
      }
      else {
        if(tblModel.getValueAt(0,colIndex) != null)
        {
          url = url + "&" + details[0] + "=" + tblModel.getValueAt(0, colIndex);
        }
      }
    }
    else {
      for(var count=0; count < details[1].length; count++)
      {  
        url = url + "&" + details[0] + "=" + details[1][count];
      }
    }
  }	
  return url;
}
